==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical/chemical/file/mol/search/by-dtxsid.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/file/mol/search/by-dtxsid/", 
    status_code = 404L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Tue, 21 May 2024 17:14:06 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "05635b2e-0982-49b6-70ec-d9c54d7603b1", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "D6iLrg42L0A8m08C6uw9lNLC3UCtdHdY9fWyt2L9LbOR00r8UinHTw=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Tue, 21 May 2024 17:14:06 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "05635b2e-0982-49b6-70ec-d9c54d7603b1", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "D6iLrg42L0A8m08C6uw9lNLC3UCtdHdY9fWyt2L9LbOR00r8UinHTw=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 0x74, 0x20, 0x46, 0x6f, 
    0x75, 0x6e, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 
    0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 
    0x30, 0x34, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 
    0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 
    0x20, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x20, 0x72, 0x65, 
    0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x20, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x66, 0x69, 0x6c, 0x65, 
    0x2f, 0x6d, 0x6f, 0x6c, 0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 
    0x68, 0x2f, 0x62, 0x79, 0x2d, 0x64, 0x74, 0x78, 0x73, 0x69, 
    0x64, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 
    0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 
    0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 
    0x2f, 0x66, 0x69, 0x6c, 0x65, 0x2f, 0x6d, 0x6f, 0x6c, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 
    0x64, 0x74, 0x78, 0x73, 0x69, 0x64, 0x2f, 0x22, 0x0a, 0x7d
    )), date = structure(1716311646, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.3e-05, 
    connect = 0, pretransfer = 0.000161, starttransfer = 0.264645, 
    total = 0.264674)), class = "response")

==> ctxR_1.1.2.tar.gz: ctxR/tests/testthat/chemical/chemical/file/mol/search/by-dtxsid.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/file/mol/search/by-dtxsid/", 
    status_code = 404L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:47:12 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "d917f76e-80b5-40dc-6b31-c8c27772a831", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "5mL8EDlVV1XKzXLzuGMEPSprNC1u1G827I1gzWLKmisNnMkSaTDWjA=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:47:12 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "d917f76e-80b5-40dc-6b31-c8c27772a831", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "5mL8EDlVV1XKzXLzuGMEPSprNC1u1G827I1gzWLKmisNnMkSaTDWjA=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 0x74, 0x20, 0x46, 0x6f, 
    0x75, 0x6e, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 
    0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 
    0x30, 0x34, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 
    0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 
    0x20, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x20, 0x72, 0x65, 
    0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x20, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x66, 0x69, 0x6c, 0x65, 
    0x2f, 0x6d, 0x6f, 0x6c, 0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 
    0x68, 0x2f, 0x62, 0x79, 0x2d, 0x64, 0x74, 0x78, 0x73, 0x69, 
    0x64, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 
    0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 
    0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 
    0x2f, 0x66, 0x69, 0x6c, 0x65, 0x2f, 0x6d, 0x6f, 0x6c, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 
    0x64, 0x74, 0x78, 0x73, 0x69, 0x64, 0x2f, 0x22, 0x0a, 0x7d
    )), date = structure(1731080832, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.6e-05, 
    connect = 0, pretransfer = 0.00017, starttransfer = 0.23765, 
    total = 0.237683)), class = "response")
